Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(857)

Unified Diff: chrome/browser/ui/ash/chrome_launcher_prefs.h

Issue 2765563002: Move and rename Chrome's AppLauncherId to ash::AppLaunchId. (Closed)
Patch Set: Add example commment. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/chrome_launcher_prefs.h
diff --git a/chrome/browser/ui/ash/chrome_launcher_prefs.h b/chrome/browser/ui/ash/chrome_launcher_prefs.h
index 1fda7a7a01d0e24f80b768e032f6dd4bd96c158f..00022aa80c474048e0b074be53c19c14b7dc3da0 100644
--- a/chrome/browser/ui/ash/chrome_launcher_prefs.h
+++ b/chrome/browser/ui/ash/chrome_launcher_prefs.h
@@ -27,7 +27,7 @@ class PrefRegistrySyncable;
namespace ash {
-class AppLauncherId;
+class AppLaunchId;
namespace launcher {
@@ -67,23 +67,23 @@ void SetShelfAlignmentPref(PrefService* prefs,
ShelfAlignment alignment);
// Get the list of pinned apps from preferences.
-std::vector<AppLauncherId> GetPinnedAppsFromPrefs(
+std::vector<AppLaunchId> GetPinnedAppsFromPrefs(
const PrefService* prefs,
LauncherControllerHelper* helper);
// Removes information about pin position from sync model for the app. Note,
-// |app_launcher_id| with non-empty launch_id is not supported.
-void RemovePinPosition(Profile* profile, const AppLauncherId& app_launcher_id);
+// |app_launch_id| with non-empty launch_id is not supported.
+void RemovePinPosition(Profile* profile, const AppLaunchId& app_launch_id);
// Updates information about pin position in sync model for the app
// |app_launcher_id|. |app_launcher_id_before| optionally specifies an app that
// exists right before the target app. |app_launcher_ids_after| optionally
// specifies sorted by position apps that exist right after the target app.
// Note, |app_launcher_id| with non-empty launch_id is not supported.
void SetPinPosition(Profile* profile,
- const AppLauncherId& app_launcher_id,
- const AppLauncherId& app_launcher_id_before,
- const std::vector<AppLauncherId>& app_launcher_ids_after);
+ const AppLaunchId& app_launch_id,
+ const AppLaunchId& app_launch_id_before,
+ const std::vector<AppLaunchId>& app_launch_ids_after);
// Used to propagate remote preferences to local during the first run.
class ChromeLauncherPrefsObserver
« no previous file with comments | « chrome/browser/ui/ash/app_list/app_list_controller_ash.cc ('k') | chrome/browser/ui/ash/chrome_launcher_prefs.cc » ('j') | no next file with comments »
@@ -67,23 +67,23 @@ void SetShelfAlignmentPref(PrefService* prefs,
// Updates information about pin position in sync model for the app
-// |app_launcher_id|. |app_launcher_id_before| optionally specifies an app that
-// exists right before the target app. |app_launcher_ids_after| optionally
+// |app_launch_id|. |app_launch_id_before| optionally specifies an app that
+// exists right before the target app. |app_launch_ids_after| optionally
// specifies sorted by position apps that exist right after the target app.
@@ -67,23 +67,23 @@ void SetShelfAlignmentPref(PrefService* prefs,
// specifies sorted by position apps that exist right after the target app.
-// Note, |app_launcher_id| with non-empty launch_id is not supported.
+// Note, |app_launch_id| with non-empty launch_id is not supported.
void SetPinPosition(Profile* profile,

Powered by Google App Engine
This is Rietveld 408576698